"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createWalkthrough = void 0;
const path = __importStar(require("path"));
const inquirer_1 = __importDefault(require("inquirer"));
const uuid_1 = require("uuid");
const templateFileName = 'amplify-console-notification-cloudformation-template.json.ejs';
/**
 * Starting point for CLI walkthrough that generates a Amplify Console Notification
 * @param context The Amplify Context object
 * @param category The resource category (should always be 'consolenotification')
 * @param options The options for Amplify Console Notification
 */
async function createWalkthrough(context, category, options) {
    const functionName = await addTrigger(context);
    options.functionName = functionName;
    await copyCfnTemplate(context, category, options);
    const backendConfigs = {
        service: options.service,
        providerPlugin: 'awscloudformation',
        dependsOn: [
            {
                category: "function",
                resourceName: functionName,
                attributes: [
                    "Arn"
                ]
            }
        ],
    };
    await context.amplify.updateamplifyMetaAfterResourceAdd(category, 'slack', backendConfigs);
}
exports.createWalkthrough = createWalkthrough;
function copyCfnTemplate(context, category, options) {
    const { amplify } = context;
    // @ts-ignore
    const targetDir = amplify.pathManager.getBackendDirPath();
    const pluginDir = path.join(__dirname, '..', '..', '..', '..');
    const copyJobs = [
        {
            dir: pluginDir,
            template: `resources/awscloudformation/cloudformation-templates/${templateFileName}`,
            target: `${targetDir}/${category}/slack/slack-cloudformation-template.json`,
            paramsFile: path.join(targetDir, category, 'slack', 'parameters.json'),
        },
    ];
    const params = {
        appId: getAppId(context)
    };
    // copy over the files
    // @ts-ignore
    return context.amplify.copyBatch(context, copyJobs, options, false, params);
}
function getAppId(context) {
    const meta = context.amplify.getProjectMeta();
    if (meta.providers && meta.providers.awscloudformation) {
        return meta.providers.awscloudformation.AmplifyAppId;
    }
}
async function addTrigger(context) {
    const questions = [
        {
            name: 'functionName',
            type: 'input',
            message: 'Input function name in order to send message to Slack.'
        },
        {
            name: 'webhookUrl',
            type: 'input',
            message: 'Input Web hook URL of Slack.'
        }
    ];
    const answers = await inquirer_1.default.prompt(questions);
    const { functionName, webhookUrl } = answers;
    // Create a new lambda trigger
    // @ts-ignore
    const targetDir = context.amplify.pathManager.getBackendDirPath();
    const pluginDir = __dirname;
    const [shortId] = uuid_1.v4().split('-');
    const defaults = {
        functionName,
        roleName: `${functionName}LambdaRole${shortId}`
    };
    const copyJobs = [
        {
            dir: pluginDir,
            template: path.join('..', '..', '..', '..', 'resources', 'triggers', 'slack', 'lambda-cloudformation-template.json.ejs'),
            target: path.join(targetDir, 'function', functionName, `${functionName}-cloudformation-template.json`),
            paramsFile: path.join(targetDir, 'function', functionName, 'parameters.json'),
        },
        {
            dir: pluginDir,
            template: path.join('..', '..', '..', '..', 'resources', 'triggers', 'slack', 'event.json'),
            target: path.join(targetDir, 'function', functionName, 'src', 'event.json'),
        },
        {
            dir: pluginDir,
            template: path.join('..', '..', '..', '..', 'resources', 'triggers', 'slack', 'index.js.ejs'),
            target: path.join(targetDir, 'function', functionName, 'src', 'index.js'),
        },
        {
            dir: pluginDir,
            template: path.join('..', '..', '..', '..', 'resources', 'triggers', 'slack', 'package.json.ejs'),
            target: path.join(targetDir, 'function', functionName, 'src', 'package.json'),
        },
    ];
    const params = {
        webhookUrl
    };
    // copy over the files
    // @ts-ignore
    await context.amplify.copyBatch(context, copyJobs, defaults, false, params);
    // Update amplify-meta and backend-config
    const backendConfigs = {
        service: 'Lambda',
        providerPlugin: 'awscloudformation',
        build: true,
    };
    await context.amplify.updateamplifyMetaAfterResourceAdd('function', functionName, backendConfigs);
    context.print.success(`Successfully added resource ${functionName} locally`);
    return functionName;
}
//# sourceMappingURL=amplify-console-notification-walkthrough.js.map